"""
MetaSpec - Meta-specification framework for generating Spec-Driven X (SD-X) toolkits.

A framework that generates complete, production-ready speck its (spec-driven toolkits)
from YAML definitions.
"""

__version__ = "0.6.4"

__all__ = ["__version__"]

